@@ -46,7 +46,7 @@ fn simple_user_journey_read_only() -> Result<()> {
             "it will not think it is still scanning as there is no traversal"
         );
 
-        let first_selected_path = OsString::from(format!("{}/{}", FIXTURE_PATH, long_root));
+        let first_selected_path = OsString::from(format!("{FIXTURE_PATH}/{long_root}"));
         assert_eq!(
             node_by_name(&app, &first_selected_path).name,
             first_selected_path,
@@ -68,6 +68,20 @@ fn simple_user_journey_read_only() -> Result<()> {
 
     // SORTING
     {
+        // when hitting the N key
+        app.process_events(&mut terminal, into_codes("n"))?;
+        assert_eq!(
+            app.state.sorting,
+            SortMode::NameAscending,
+            "it sets the sort mode to ascending by name"
+        );
+        // when hitting the N key again
+        app.process_events(&mut terminal, into_codes("n"))?;
+        assert_eq!(
+            app.state.sorting,
+            SortMode::NameDescending,
+            "it sets the sort mode to descending by name"
+        );
         // when hitting the M key
         app.process_events(&mut terminal, into_codes("m"))?;
         assert_eq!(
@@ -301,9 +315,10 @@ fn simple_user_journey_read_only() -> Result<()> {
                 "it marks only a single node",
             );
             assert!(
-                app.window.mark_pane.as_ref().map_or(false, |p| p
-                    .marked()
-                    .contains_key(&previously_selected_index)),
+                app.window
+                    .mark_pane
+                    .as_ref()
+                    .is_some_and(|p| p.marked().contains_key(&previously_selected_index)),
                 "it marks the selected node"
             );
             assert_eq!(
@@ -341,9 +356,10 @@ fn simple_user_journey_read_only() -> Result<()> {
             );
 
             assert!(
-                app.window.mark_pane.as_ref().map_or(false, |p| p
-                    .marked()
-                    .contains_key(&previously_selected_index)),
+                app.window
+                    .mark_pane
+                    .as_ref()
+                    .is_some_and(|p| p.marked().contains_key(&previously_selected_index)),
                 "it leaves the first selected item marked"
             );
         }
