@@ -1,7 +1,9 @@
 use crate::interactive::app::tests::utils::{
     debug, initialized_app_and_terminal_from_fixture, sample_01_tree, sample_02_tree,
 };
+use crate::interactive::widgets::glob_search;
 use anyhow::Result;
+use dua::traverse::TreeIndex;
 use pretty_assertions::assert_eq;
 
 #[test]
@@ -20,7 +22,7 @@ fn it_can_handle_ending_traversal_reaching_top_but_skipping_levels() -> Result<(
 #[test]
 fn it_can_handle_ending_traversal_without_reaching_the_top() -> Result<()> {
     let (_, app) = initialized_app_and_terminal_from_fixture(&["sample-02"])?;
-    let expected_tree = sample_02_tree();
+    let (expected_tree, _) = sample_02_tree(true);
 
     assert_eq!(
         debug(app.traversal.tree),
@@ -29,3 +31,11 @@ fn it_can_handle_ending_traversal_without_reaching_the_top() -> Result<()> {
     );
     Ok(())
 }
+
+#[test]
+fn it_can_do_a_glob_search() {
+    let (tree, root_index) = sample_02_tree(false);
+    let result = glob_search(&tree, root_index, "tests/fixtures/sample-02").unwrap();
+    let expected = vec![TreeIndex::from(1)];
+    assert_eq!(result, expected);
+}
